@@ -1,4 +1,3 @@
-
 #define MAX_TAGNAMELENGTH 20
 #define MAX_STRIPTAGS 20
 
@@ -26,12 +25,16 @@ typedef struct Stripper {
   char o_striptags[MAX_STRIPTAGS][MAX_TAGNAMELENGTH];
   int numstriptags;
   int o_emit_spaces;
+  int o_decode_entities;
+
+  int o_auto_reset;
+
+  int o_debug;
 } Stripper;
 
-void strip_html( Stripper * stripper, const char * raw, char * clean );
-void reset( Stripper * stripper );
+void _strip_html( Stripper * stripper, char * raw, char * clean );
+void _reset( Stripper * stripper );
 void clear_striptags( Stripper * stripper );
 void add_striptag( Stripper * stripper, char * tag );
-void set_emit_spaces( Stripper * stripper, int emit );
 
 void check_end( Stripper * stripper, char );
